@@ -35,9 +35,7 @@ detailed explanation.
 
 import inspect
 import json
-import copy
 from contextlib import contextmanager
-from datetime import datetime
 
 from jsonweb.schema.validators import EnsureType
 from jsonweb.exceptions import JsonWebError
@@ -71,7 +69,7 @@ class ObjectAttributeError(ObjectDecodeError):
     def __init__(self, obj_type, attr):
         ObjectDecodeError.__init__(
             self,
-            "Missing %s attribute for %s." % (attr, obj_type), 
+            "Missing {0} attribute for {1}.".format(attr, obj_type),
             obj_type=obj_type, 
             attribute=attr
         )
@@ -81,7 +79,7 @@ class ObjectNotFoundError(ObjectDecodeError):
     def __init__(self, obj_type):
         ObjectDecodeError.__init__(
             self,
-            "Cannot decode object %s. No such object." % obj_type, 
+            "Cannot decode object {0}. No such object.".format(obj_type),
             obj_type=obj_type,
         )
 
@@ -186,8 +184,7 @@ class ObjectHook(object):
     json into python class instances. You should not need to use this class
     directly. :func:`object_hook` is responsible for instantiating and using it.
     """
-    _DT_FORMAT = _DATETIME_FORMAT
-            
+
     def __init__(self, handlers, validate=True):
         self.handlers = handlers
         self.validate = validate
@@ -218,20 +215,6 @@ class ObjectHook(object):
         except KeyError, e:
             raise ObjectAttributeError(obj_type, e.args[0])
         
-    def _datetime(self, dt):
-        if dt is None:
-            return
-        try:
-            return datetime.strptime(dt, self._DT_FORMAT)
-        except TypeError, e:
-            raise ObjectDecodeError(
-                "datetime attribute for %s must be a string, not %s" %
-                (self.obj, type(dt))
-            )
-
-        except ValueError, e:
-            raise ObjectDecodeError(e.args[0])
-
 
 def get_arg_spec(func):
     arg_spec = inspect.getargspec(func)
@@ -257,8 +240,8 @@ def get_arg_spec(func):
 def get_jsonweb_handler(cls):
     arg_spec = get_arg_spec(cls.__init__)
     if arg_spec is None:
-        raise JsonWebError("Unable to generate an object_hook handler "
-                           "from %s's `__init__` method." % cls.__name__)
+        raise JsonWebError("Unable to generate an object_hook handler from "
+                           "{0}'s `__init__` method.".format(cls.__name__))
     args, kw = get_arg_spec(cls.__init__)
 
     return JsonWebObjectHandler(args, kw or None)
